@@ -1,5 +1,5 @@
 `dbFD` <-
-function(x, a , w, w.abun = TRUE, stand.x = TRUE, ord = c("podani", "metric"), asym.bin = NULL, corr = c("sqrt", "cailliez", "lingoes", "none"),  calc.FRic = TRUE, m = "max", stand.FRic = TRUE, scale.RaoQ = FALSE, calc.FGR = FALSE, clust.type = "ward", km.inf.gr = 2, km.sup.gr = nrow(x) - 1, km.iter = 100, km.crit = c("calinski", "ssi"),  calc.CWM = TRUE, CWM.type = c("dom", "all"), calc.FDiv = TRUE, dist.bin = 2, print.pco = FALSE, messages = TRUE){
+function(x, a , w, w.abun = TRUE, stand.x = TRUE, ord = c("podani", "metric"), asym.bin = NULL, corr = c("sqrt", "cailliez", "lingoes", "none"),  calc.FRic = TRUE, m = "max", stand.FRic = FALSE, scale.RaoQ = FALSE, calc.FGR = FALSE, clust.type = "ward", km.inf.gr = 2, km.sup.gr = nrow(x) - 1, km.iter = 100, km.crit = c("calinski", "ssi"),  calc.CWM = TRUE, CWM.type = c("dom", "all"), calc.FDiv = TRUE, dist.bin = 2, print.pco = FALSE, messages = TRUE){
 
 # get tolerance value specifying small values that should be 0
 tol <- .Machine$double.eps
@@ -254,7 +254,7 @@ if (any(is.na(x.dist) ) ) stop("NA's in the distance matrix.","\n")
 # check whether one or more species has no traits
 if (!is.dist.x)
 {
-	no.traits <- apply(x, 2, function(v) length(v[!is.na(v)]) )
+	no.traits <- apply(x, 1, function(v) length(v[!is.na(v)]) )
 	if (any(no.traits == 0) ) stop("At least one species has no trait data.","\n")
 }
 # c = number of communities
